/** Types of the messages that the client-side console relay sends on the web
 * socket to the server. */
export declare type ConsoleMethodName = 'clear' | 'debug' | 'error' | 'info' | 'log' | 'warn';
export declare type ConnectionMessage = {
    type: 'opened';
};
export declare type ConsoleMethodMessage = {
    method: ConsoleMethodName;
};
export declare type DocumentMessage = {
    type: 'visibilitychange';
    visibilityState?: typeof document.visibilityState;
};
export declare type ErrorMessage = {
    type: 'error';
    message: string;
    url?: string;
    line?: number;
    col?: number;
    stack?: string;
};
export declare type UnhandledRejectionMessage = {
    type: 'unhandledRejection';
    message: string;
    stack: string;
};
export declare type WindowMessage = {
    type: 'load' | 'pagehide' | 'DOMContentLoaded';
};
export declare type MessageCore = ConnectionMessage | ConsoleMethodMessage | DocumentMessage | ErrorMessage | UnhandledRejectionMessage | WindowMessage;
export declare type Message = MessageCore & {
    stack?: string;
    timestamp: string;
    url?: string;
};
