/// <reference types="node" />
import { Request, Response } from 'express-serve-static-core';
import { EventEmitter } from 'stream';
import { MountPointOptions } from './routes';
import http = require('http');
export declare namespace Server {
    type Options = Partial<{
        /** The http port number. Defaults to 3000. */
        port: number;
        /** If true, then if the specified port number is not available, find another port. Defaults to true. */
        scanPorts: boolean;
        /** The base directory. Defaults to the current working directory. */
        root: string | null;
        /** A list of base directories and optional URL path prefixes. If this is
         * present, it is used instead of the root option. */
        mountPoints: MountPointOptions[];
        /** If true, relay console events from the sketch to an emitter on the server. */
        relayConsoleMessages: boolean;
        /** Inject the live reload websocket listener into HTML pages. */
        liveServer: boolean;
        /** Sketches send screenshot data to this handler. */
        screenshot: Partial<{
            canvasDimensions: {
                width: number;
                height: number;
            };
            frameCount: number;
            imageType: 'png' | 'jpeg';
            pixelDensity: number;
            skipFrames: number;
            onFrameData: (data: {
                data: Buffer;
                frameNumber: number;
                imageType: string;
            }) => void | Promise<void>;
        }> | null;
        theme?: string;
    }>;
}
export declare type RouterConfig = Server.Options & {
    root: string;
    sketchFile?: string;
};
declare type MountPoint = {
    filePath: string;
    urlPath: string;
    name?: string;
};
export declare function sendDirectoryListing<T>(config: RouterConfig, req: Request<unknown, unknown, unknown, unknown, T>, res: Response<unknown, T>): Promise<void | Response<unknown, T, number>>;
/** Server is a web server with live reload, sketch-aware directory listings,
 * and library inference for JavaScript-only sketches.
 */
export declare class Server {
    server: http.Server | null;
    url?: string;
    mountPoints: MountPoint[];
    private readonly config;
    private liveReloadServer;
    private readonly browserScriptEmitter;
    readonly emitScriptEvent: (eventName: string | symbol, ...args: any[]) => boolean;
    readonly onScriptEvent: (eventName: string | symbol, listener: (...args: any[]) => void) => EventEmitter;
    constructor(options?: Partial<Server.Options>);
    /** Create and start the server. Returns the instance. */
    static start(options?: Partial<Server.Options>): Promise<Server>;
    start(): Promise<this>;
    /**
     * Close the server and the liveServer.
     *
     * Note: Can return before the liveServer is stopped.
     */
    close(): Promise<void>;
    filePathToUrl(filePath: string): string | null;
    urlPathToFilePath(urlPath: string): string | null;
    serverUrlToFileUrl(url: string): string | null;
    private static normalizeMountPoints;
}
export {};
